config

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 30, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var DefaultConfigFiles = []string{".testris.yaml", ".testris.yml"}

DefaultConfigFiles are the filenames searched for config (in order).

Functions

This section is empty.

Types

type Config

type Config struct {
	Timing  string   `yaml:"timing"`
	GroupBy string   `yaml:"group_by"`
	Include []string `yaml:"include"`
	Format  string   `yaml:"format"`
}

Config holds project-specific testris settings.

func Load

func Load(dir string) (*Config, error)

Load attempts to load config from the default locations. Returns an empty config if no file is found (not an error).

func LoadFile

func LoadFile(path string) (*Config, error)

LoadFile loads config from a specific file path.

Jump to